﻿* Encoding: UTF-8.

*This code should be run on the working version of my dataset, which was created by running 
      my syntax file that created the small version of the dataset and saved a copy as the working 
      version.The small version dropped many irrelevant variables as well as everyone who didn't 
      indicate on vb2 that they were a voter.
      
  * When recoding variables to replicate the Bolsonaro study (more or less--not all of the variables are 
    the same here) , when I messed up on coding a variable, I just deleted the new variable by selecting 
    and clearing it in the data editor. Each time I created a new variable, I followed the same 4 steps:
    (1) I used a CODEBOOK command on the original variable to make sure I knew its numbering scheme;
    (2) I coded the new variable, labeled it, and labeled its response categories;  
    (3) I ran a FREQUENCY command on both the original and new variable and carefully compared 
    respondent counts in each category to make sure that  everything--including missing respondents
    were coded correctly on the new variable; and 
    (4) I deleted and redid any variable where there was a mistake.

*I didn't originally recode the variables in the same order as they appeared in the Bolsonaro article. When
    I was done and everything looked good with the coding, I recreated the original working version of the
    dataset using the small version syntax. Then, I moved the order of my recoding syntax around so I could rerun
    all of the code below and recreate variables in the order I wanted them to be in. If I were completely satisfied 
    with the final product, I might add a DELETE VARIABLES command to the end of my coding and then 
    list the variables I wanted removed from the working version of the dataset. I didn't do this here because
    we'll be using this dataset for SPSS exercises and I want to keep several kinds of variables. In the 
    Bosonaro article, all of the variables were either 0/1 dummy variables or recoded to range from 0 to 1. 

    **********************************************************************************************
    **********************************************************************************************
    **********************************************************************************************
    **********************************************************************************************

* Create the study's DV. This dummy variable identifies people who voted for Bolsonaro in the first round of the 2018 election
    People who said they cast blank or missing ballots are coded as not voting for Bolsonaro.    
    

        RECODE vb3n  (SYSMIS = SYSMIS) (1501=1) (ELSE=0) INTO VotedForBolsonaro.
        VARIABLE LABELS  VotedForBolsonaro 'Voted for Bolsonaro'.
        VALUE LABELS VotedForBolsonaro
        1 "Voted for Bolsonaro"
        0 "Didn't vote for him"
        .
        EXECUTE.

    *Running a frequency on the DV, I see that a substantial number of respondents--145 of them--are listed 
      as missing data even though they said on vb2 that they voted in the election.  Per the questionaire, this 
      means that they responded "don't know" or refused to answer this question. They will be dropped from 
      the working version of the dataset so that my descriptive stats aren't off for the other variables in case the 
      folks who didn't answer this question are subtantially different from those who did. 

    FILTER OFF.
    USE ALL.
    SELECT IF (NOT MISSING(vb3n)).
    EXECUTE.


* Create a dummy variable for male. Every respondent in the survey self-identified as either male or female. 

    RECODE q1 (SYSMIS = SYSMIS) (1=1) (ELSE=0) INTO Male.
    VARIABLE LABELS  Male 'Respondent is male'.
    VALUE LABELS Male
    1 "Male"
    0 "Female"
    .
    EXECUTE.

     
*BEGIN INDEP. VARIABLES HERE. Note, these aren't exactly the same as in the Bolsonaro article.

*Create a dummy for AfroBrazilian dummy
    
       CODEBOOK  etid [n]
      /VARINFO POSITION LABEL TYPE FORMAT MEASURE ROLE VALUELABELS MISSING ATTRIBUTES
      /OPTIONS VARORDER=VARLIST SORT=ASCENDING MAXCATS=200
      /STATISTICS COUNT PERCENT MEAN STDDEV QUARTILES.
      
    COMPUTE AfroBrazilian= $SYSMIS.
    IF etid > 0   AfroBrazilian = 0. 
    IF etid = 4   AfroBrazilian = 1. 
    IF etid = 5   AfroBrazilian = 1. 
    VARIABLE LABELS  AfroBrazilian  'Respondent is AfroBrazilian'.
    VALUE LABELS AfroBrazilian
    1 "AfroBrazilian"
    0 "Other race"
    .
    EXECUTE.
      
 
*White Brazilian dummy

    COMPUTE White= $SYSMIS.
    IF etid = 1   White = 1. 
    IF etid >1   White = 0. 
   VARIABLE LABELS  White  'Respondent is white'.
    VALUE LABELS White
    1 "Respondent is white"
    0 "non-white"
    .
    EXECUTE.
    
*Nonwhite, non AfroBraziian dummy

    COMPUTE OtherRace= $SYSMIS.
    IF etid > 0   OtherRace = 1. 
    IF etid = 1   OtherRace = 0. 
    IF etid = 4   OtherRace = 0. 
    IF etid = 5   OtherRace = 0. 
    VARIABLE LABELS  OtherRace  'Respondent is neither AfroBrazilian, nor white'.
    VALUE LABELS OtherRace
    1 "Respondent is neither AfroBrazilian, nor white"
    0 "AfroBrazilian or white"
    .
    EXECUTE.
    
*Age 35 and older. Brazilians can vote at 16. A frequency shows that respondents
    ages varied from 16 to 83 years old
    
     COMPUTE AtLeast35yrs= $SYSMIS.
    IF q2 > 34   AtLeast35yrs = 1. 
    IF q2 <35   AtLeast35yrs = 0. 
    VARIABLE LABELS  AtLeast35yrs  'Respondent is age 35 or older'.
    VALUE LABELS AtLeast35yrs
    1 "Respondent is age 35 or older"
    0 "Younger than 25"
    .
    EXECUTE.

 
*At least HS dummy var - defined as 11 or more yrs of fomal schooling.
    RECODE ed (SYSMIS=SYSMIS) (MISSING=SYSMIS) (0 thru 10=0) (11 thru Highest=1) INTO AtLeastHS.
    VARIABLE LABELS  AtLeastHS 'R as at least 11 years of schooling'.
    VALUE LABELS AtLeastHS
    1 "R. has HS edu or higher"
    0 "HS not completed"
    .
    EXECUTE.
    

*Rural resident dummy. (The Bolsonaro article has a regional variable. For this exercise, I am going to substitute 
    rural vs. urban. 
    
    COMPUTE Rural= $SYSMIS.
    IF ur = 2   Rural = 1. 
    IF ur = 1   Rural = 0. 
    VARIABLE LABELS  Rural  'Respondent lives in rural area'.
    VALUE LABELS Rural
    1 "Respondent lives in rural area"
    0 "Urban area"
    .
    EXECUTE.


*Income omitted. Bolsonaro article had an income variable. We'll leave that out of this exercise.

*Evangelical Prot. dummy. Notice the series of IF statements to 
    logically flip response categories to isolate 5 = Evan Prot. 
    
    COMPUTE EvanProt= $SYSMIS.
    IF q3cn > 0   EvanProt = 0. 
    IF q3cn = 5   EvanProt = 1. 
    IF q3cn > 5   EvanProt = 0.
    VARIABLE LABELS  EvanProt  'Respondent is an evangel. Protestant'.
    VALUE LABELS EvanProt
    1 "Respondent is an evangel. Protestant"
    0 "Not an evan Prot."
    .
    EXECUTE.

*Conservative: 10-point level measure of ideology
    
    COMPUTE Conservative10=  l1.
    IF l1 = $SYSMIS   Conservative10 = $SYSMIS. 
    VARIABLE LABELS  Conservative10  'R. is more conservative, 1-10 '.
    VALUE LABELS Conservative10
    1 "Left"
    10 "Right"
    .
    EXECUTE.

*Conservative ideology, 0-1 version.

    COMPUTE Conservative0to1=  (l1-1)/9.
    IF l1 = $SYSMIS   Conservative0to1 = $SYSMIS. 
    VARIABLE LABELS  Conservative0to1  'R. is more conservative, 0-1 '.
    VALUE LABELS Conservative0to1
    0 "Left"
    1 "Right"
    .
    EXECUTE.


*Dislike of the left-learning Brazilian Workers Party - 10-point measure.
    COMPUTE DislikePT10 =  11 - braantip1.
    IF braantip1 = $SYSMIS   DislikePT10 = $SYSMIS. 
    VARIABLE LABELS  DislikePT10  'R. dislikes the PT, 1-10 '.
    VALUE LABELS DislikePT10
    1 "Very much likes the Workers Party"
    10 "Very much dislikes the PT"
    .
    EXECUTE.

*Dislike of Workers Party - 0 to 1  point measure.
    COMPUTE DislikePT0to1 =  ((11 - braantip1)-1)/9.
    IF braantip1 = $SYSMIS   DislikePT0to1 = $SYSMIS. 
    VARIABLE LABELS  DislikePT0to1  'R. dislikes the PT, 0 to 1 rescale '.
    VALUE LABELS DislikePT0to1
    0 "Very much likes the Workers Party"
    1 "Very much dislikes the PT"
    .
    EXECUTE.


 *Personal economic situation-- Dummy variable in last year has gotten worse. 
    
    RECODE idio2 (SYSMIS = SYSMIS) (3=1) (ELSE=0) INTO EconWorseForMe.
    VARIABLE LABELS  EconWorseForMe 'R. econ. sit. is worse'.
    VALUE LABELS EconWorseForMe
    1 "R.'s econ. sit. is worse"
    0 "R.'s econ. same or better"
    .
    EXECUTE.


*Anti-democratic, 4-point measure. From the article: "The item was recoded into four levels that 
distinguish respondents who disagree that democracy is best (i.e., were in the top bottom 
of the scale before recoding) from those who agree to varying degrees that it is the best system." 
This phrasing isn't very clear, and in this version of the variable, the most hostile to democracy (2,3 on ing4 
are grouped into one category). 

    COMPUTE AntiDemocratic4= $SYSMIS.
    IF ing4 =1 AntiDemocratic4 = 4. 
    IF ing4 =2 AntiDemocratic4 = 3.
    IF ing4 =3 AntiDemocratic4 = 3.
    IF ing4 =4 AntiDemocratic4 = 2.
    IF ing4 >4 AntiDemocratic4 = 1.
    VARIABLE LABELS  AntiDemocratic4  'Disagrees democracy is best, 4 level'.
    VALUE LABELS AntiDemocratic4
    4 "Strongly disagrees democ is best"
    1 "In the bottom half of the original 7-pt measure"
    .
    EXECUTE.

    *Rescale anti-democratic measure to range from 0 to 1. 
    COMPUTE AntiDemocratic0to1= (AntiDemocratic4-1)/3.
    VARIABLE LABELS  AntiDemocratic0to1  'Disagrees democracy is best, 0 to 1 rescale'.
    VALUE LABELS AntiDemocratic0to1
    1 "Strongly disagrees democ is best"
    0 "In the bottom half of the original 7-pt measure"
    .
    EXECUTE.

*Thinks coups can be justified dummy. Half the sample asked whether coups could be justified in 
    time of high crime; the other half, in times of high corruption. Those items were combined here to keep
    the sample size sufficiently large. 

    COMPUTE CoupSupport= 1.
    IF jc10 =2 CoupSupport = 0. 
    IF jc13 =2 CoupSupport = 0. 
    VARIABLE LABELS  CoupSupport  'Believes coups can be justifed'.
    VALUE LABELS CoupSupport
    1 "Respondent says coups can be justified"
    0 "Respondent rejects coups in tough times"
    .
    EXECUTE.
    
*Sexism. Per the article, "Respondents were coded into three levels of sexism,
depending on whether they strongly disagreed, disagreed, or agreed with the
statement that "Generally speaking, men make better political leaders than women." 

    *3-level measure.
    COMPUTE Sexism3= $SYSMIS.
    IF vb50 =1 Sexism3 = 3. 
    IF vb50 =2 Sexism3 = 3. 
    IF vb50 = 3 Sexism3 = 2. 
    IF vb50 = 4 Sexism3 = 1. 
    VARIABLE LABELS  Sexism3  'Sexism, 3 level'.
    VALUE LABELS Sexism3
    3 "Agrees men better pol leaders"
    1 "Strongly disagrees men better leaders"
    .
    EXECUTE.

    *0-1 rescaled measure. 
   COMPUTE Sexism0to1 = (Sexism3-1)/2.
    VARIABLE LABELS  Sexism0to1  'Sexism, , 0 to 1 rescaled'.
    VALUE LABELS Sexism0to1
    1 "Agrees men better pol leaders"
    0 "Strongly disagrees men better leaders"
    .
    EXECUTE.


*Homophobia. Per article:  the measure of homophobia is a question asking respondents
how much they approve/disapprove (self-placement on a 10-point scale) with the
liberty of ‘homosexuals’ to run for public office. 

    *Homophobic- 10 point measure.
    COMPUTE Homophobic10 =  11 - d5.
    IF d5 = $SYSMIS   Homophobic10 = $SYSMIS. 
    VARIABLE LABELS  Homophobic10  'R. is homophobic, 1-10 '.
    VALUE LABELS Homophobic10
    1 "Strongly approves that gay folks have right to run for office"
    10 "Strongly disapproves"
    .
    EXECUTE.

    *Homophobic- 0 to1 point measure.
    COMPUTE Homophobic0to1 =   ((11 - d5)-1)/9.
    IF d5 = $SYSMIS   Homophobic0to1 = $SYSMIS. 
    VARIABLE LABELS  Homophobic0to1  'R. is homophobic, 0-1 rescaled '.
    VALUE LABELS Homophobic0to1
    0 "Strongly approves that gay folks have right to run for office"
    1 "Strongly disapproves"
    .
    EXECUTE.


*Once you are done coding, make sure to to save the your syntax as well as the dataset with 
    the new variables. If you need to make changes later on, you can just recreate the original
    version of the working dataset, correct the coding, and rerun this full syntax file. 






